use crate::prelude::*;
use teloxide::types::ParseMode;
use tokio::task::spawn_blocking;

/// Gets the master password, decryptes the account and sends it to the user with copyable fields
async fn get_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    dialogue: MainDialogue,
    ids: MessageIds,
    name: String,
    master_pass: String,
) -> crate::Result<()> {
    ids.delete(&bot).await;
    dialogue.exit().await?;

    let user_id = msg.from().ok_or(NoUserInfo)?.id.0;
    let account = match Account::get(user_id, &name, &db).await? {
        Some(account) => account,
        None => {
            bot.send_message(msg.chat.id, "Account not found")
                .reply_markup(deletion_markup())
                .await?;
            return Ok(());
        }
    };
    let (login, password) = spawn_blocking(move || account.decrypt(&master_pass)).await??;
    let message = format!("Name:\n`{name}`\nLogin:\n`{login}`\nPassword:\n`{password}`");
    bot.send_message(msg.chat.id, message)
        .reply_markup(deletion_markup())
        .parse_mode(ParseMode::MarkdownV2)
        .await?;
    Ok(())
}

handler!(get_account_name(name:String), "Send master password", State::GetMasterPass, get_master_pass);
ask_name_handler!(
    get_account,
    "Send the name of the account to get",
    get_account_name
);
